@@ -2,11 +2,20 @@
 Base Class for DesktopEntry, IconTheme and IconData
 """
 
-import re, os, stat, codecs, sys
-from xdg.Exceptions import *
+import re, os, stat, io
+from xdg.Exceptions import (ParsingError, DuplicateGroupError, NoGroupError,
+                            NoKeyError, DuplicateKeyError, ValidationError,
+                            debug)
 import xdg.Locale
+from xdg.util import u
 
-PY3 = sys.version_info[0] >= 3
+def is_ascii(s):
+    """Return True if a string consists entirely of ASCII characters."""
+    try:
+        s.encode('ascii', 'strict')
+        return True
+    except UnicodeError:
+        return False
 
 class IniFile:
     defaultGroup = ''
@@ -36,7 +45,7 @@ class IniFile:
             raise ParsingError("File not found", filename)
 
         try:
-            fd = open(filename, 'r')
+            fd = io.open(filename, 'r', encoding='utf-8')
         except IOError as e:
             if debug:
                 raise e
@@ -112,9 +121,7 @@ class IniFile:
             values = [value]
 
         for value in values:
-            if type == "string" and locale == True and not PY3:
-                value = value.decode("utf-8", "ignore")
-            elif type == "boolean":
+            if type == "boolean":
                 value = self.__getBoolean(value)
             elif type == "integer":
                 try:
@@ -129,7 +136,8 @@ class IniFile:
             elif type == "regex":
                 value = re.compile(value)
             elif type == "point":
-                value = value.split(",")
+                x, y = value.split(",")
+                value = int(x), int(y)
 
             if list == True:
                 result.append(value)
@@ -176,7 +184,11 @@ class IniFile:
 
     # start validation stuff
     def validate(self, report="All"):
-        "validate ... report = All / Warnings / Errors"
+        """Validate the contents, raising ``ValidationError`` if there
+        is anything amiss.
+        
+        report can be 'All' / 'Warnings' / 'Errors'
+        """
 
         self.warnings = []
         self.errors = []
@@ -275,15 +287,7 @@ class IniFile:
             return 1
 
     def checkString(self, value):
-        if PY3:
-            try:
-                value.encode('ascii', 'strict')
-                return 0
-            except UnicodeError:
-                return 1
-        # convert to ascii
-        if not value.decode("utf-8", "ignore").encode("ascii", 'ignore') == value:
-            return 1
+        return 0 if is_ascii(value) else 1
 
     def checkRegex(self, value):
         try:
@@ -304,26 +308,26 @@ class IniFile:
         if os.path.dirname(filename) and not os.path.isdir(os.path.dirname(filename)):
             os.makedirs(os.path.dirname(filename))
 
-        fp = codecs.open(filename, 'w')
+        with io.open(filename, 'w', encoding='utf-8') as fp:
 
-        # An executable bit signifies that the desktop file is
-        # trusted, but then the file can be executed. Add hashbang to
-        # make sure that the file is opened by something that
-        # understands desktop files.
-        if trusted:
-            fp.write("#!/usr/bin/env xdg-open\n")
+            # An executable bit signifies that the desktop file is
+            # trusted, but then the file can be executed. Add hashbang to
+            # make sure that the file is opened by something that
+            # understands desktop files.
+            if trusted:
+                fp.write(u("#!/usr/bin/env xdg-open\n"))
 
-        if self.defaultGroup:
-            fp.write("[%s]\n" % self.defaultGroup)
-            for (key, value) in self.content[self.defaultGroup].items():
-                fp.write("%s=%s\n" % (key, value))
-            fp.write("\n")
-        for (name, group) in self.content.items():
-            if name != self.defaultGroup:
-                fp.write("[%s]\n" % name)
-                for (key, value) in group.items():
-                    fp.write("%s=%s\n" % (key, value))
-                fp.write("\n")
+            if self.defaultGroup:
+                fp.write(u("[%s]\n") % self.defaultGroup)
+                for (key, value) in self.content[self.defaultGroup].items():
+                    fp.write(u("%s=%s\n") % (key, value))
+                fp.write(u("\n"))
+            for (name, group) in self.content.items():
+                if name != self.defaultGroup:
+                    fp.write(u("[%s]\n") % name)
+                    for (key, value) in group.items():
+                        fp.write(u("%s=%s\n") % (key, value))
+                    fp.write(u("\n"))
 
         # Add executable bits to the file to show that it's trusted.
         if trusted:
@@ -342,10 +346,7 @@ class IniFile:
             key = key + "[" + xdg.Locale.langs[0] + "]"
 
         try:
-            if (not PY3) and isinstance(value, unicode):
-                self.content[group][key] = value.encode("utf-8", "ignore")
-            else:
-                self.content[group][key] = value
+            self.content[group][key] = value
         except KeyError:
             raise NoGroupError(group, self.filename)
             
