@@ -27,7 +27,7 @@ import fnmatch
 import xdg.BaseDirectory
 import xdg.Locale
 
-from xml.dom import Node, minidom, XML_NAMESPACE
+from xml.dom import minidom, XML_NAMESPACE
 
 FREE_NS = 'http://www.freedesktop.org/standards/shared-mime-info'
 
@@ -45,7 +45,11 @@ def _get_node_data(node):
     return ''.join([n.nodeValue for n in node.childNodes]).strip()
 
 def lookup(media, subtype = None):
-    "Get the MIMEtype object for this type, creating a new one if needed."
+    """Get the MIMEtype object for this type, creating a new one if needed.
+    
+    The name can either be passed as one part ('text/plain'), or as two
+    ('text', 'plain').
+    """
     if subtype is None and '/' in media:
         media, subtype = media.split('/', 1)
     if (media, subtype) not in types:
@@ -91,7 +95,7 @@ class MIMEtype:
         return self.media + '/' + self.subtype
 
     def __repr__(self):
-        return '[%s: %s]' % (self, self._comment or '(comment not loaded)')
+        return '<%s: %s>' % (self, self._comment or '(comment not loaded)')
 
 class MagicRule:
     def __init__(self, f):
@@ -237,48 +241,48 @@ class MagicDB:
         self.maxlen=0
 
     def mergeFile(self, fname):
-        f = open(fname, 'rb')
-        line = f.readline()
-        if line != b'MIME-Magic\0\n':
-            raise IOError('Not a MIME magic file')
+        with open(fname, 'rb') as f:
+            line = f.readline()
+            if line != b'MIME-Magic\0\n':
+                raise IOError('Not a MIME magic file')
 
-        while True:
-            shead = f.readline().decode('ascii')
-            #print shead
-            if not shead:
-                break
-            if shead[0] != '[' or shead[-2:] != ']\n':
-                raise ValueError('Malformed section heading')
-            pri, tname = shead[1:-2].split(':')
-            #print shead[1:-2]
-            pri = int(pri)
-            mtype = lookup(tname)
+            while True:
+                shead = f.readline().decode('ascii')
+                #print shead
+                if not shead:
+                    break
+                if shead[0] != '[' or shead[-2:] != ']\n':
+                    raise ValueError('Malformed section heading')
+                pri, tname = shead[1:-2].split(':')
+                #print shead[1:-2]
+                pri = int(pri)
+                mtype = lookup(tname)
 
-            try:
-                ents = self.types[pri]
-            except:
-                ents = []
-                self.types[pri] = ents
+                try:
+                    ents = self.types[pri]
+                except:
+                    ents = []
+                    self.types[pri] = ents
 
-            magictype = MagicType(mtype)
-            #print tname
+                magictype = MagicType(mtype)
+                #print tname
 
-            #rline=f.readline()
-            c=f.read(1)
-            f.seek(-1, 1)
-            while c and c != b'[':
-                rule=magictype.getLine(f)
-                #print rule
-                if rule and rule.getLength() > self.maxlen:
-                    self.maxlen = rule.getLength()
-
-                c = f.read(1)
+                #rline=f.readline()
+                c=f.read(1)
                 f.seek(-1, 1)
+                while c and c != b'[':
+                    rule=magictype.getLine(f)
+                    #print rule
+                    if rule and rule.getLength() > self.maxlen:
+                        self.maxlen = rule.getLength()
 
-            ents.append(magictype)
-            #self.types[pri]=ents
-            if not c:
-                break
+                    c = f.read(1)
+                    f.seek(-1, 1)
+
+                ents.append(magictype)
+                #self.types[pri]=ents
+                if not c:
+                    break
 
     def match_data(self, data, max_pri=100, min_pri=0):
         for priority in sorted(self.types.keys(), reverse=True):
@@ -329,7 +333,8 @@ def _cache_database():
 
     def _import_glob_file(path):
         """Loads name matching information from a MIME directory."""
-        for line in open(path):
+        with open(path) as f:
+          for line in f:
             if line.startswith('#'): continue
             line = line[:-1]
 
@@ -396,17 +401,25 @@ def get_type_by_contents(path, max_pri=100, min_pri=0):
     return magic.match(path, max_pri, min_pri)
 
 def get_type_by_data(data, max_pri=100, min_pri=0):
-    """Returns type of the data"""
+    """Returns type of the data, which should be bytes."""
     if not _cache_uptodate:
         _cache_database()
 
     return magic.match_data(data, max_pri, min_pri)
 
-def get_type(path, follow=1, name_pri=100):
+def get_type(path, follow=True, name_pri=100):
     """Returns type of file indicated by path.
-    path     - pathname to check (need not exist)
-    follow   - when reading file, follow symbolic links
-    name_pri - Priority to do name matches.  100=override magic"""
+    
+    path :
+      pathname to check (need not exist)
+    follow :
+      when reading file, follow symbolic links
+    name_pri :
+      Priority to do name matches.  100=override magic
+    
+    This tries to use the contents of the file, and falls back to the name. It
+    can also handle special filesystem objects like directories and sockets.
+    """
     if not _cache_uptodate:
         _cache_database()
     
@@ -438,8 +451,8 @@ def get_type(path, follow=1, name_pri=100):
     return inode_door
 
 def install_mime_info(application, package_file):
-    """Copy 'package_file' as ~/.local/share/mime/packages/<application>.xml.
-    If package_file is None, install <app_dir>/<application>.xml.
+    """Copy 'package_file' as ``~/.local/share/mime/packages/<application>.xml.``
+    If package_file is None, install ``<app_dir>/<application>.xml``.
     If already installed, does nothing. May overwrite an existing
     file with the same name (if the contents are different)"""
     application += '.xml'
